pub struct Subscription(/* private fields */);Expand description
An active subscription.
Implementations
Sourceimpl Subscription
impl Subscription
Sourcepub async fn pipe_from_stream<S, T, B>(&self, stream: S, buf: B)
pub async fn pipe_from_stream<S, T, B>(&self, stream: S, buf: B)
Feed items to the subscription from the underlying stream with specified buffer strategy.
Sourcepub async fn pipe_from_try_stream<S, T, B, E>(
&self,
stream: S,
buf: B,
) -> Result<(), E>
pub async fn pipe_from_try_stream<S, T, B, E>( &self, stream: S, buf: B, ) -> Result<(), E>
Feed items to the subscription from the underlying stream with specified buffer strategy.
Sourcepub async fn send(&self, result: &impl Serialize) -> Result<(), DisconnectError>
pub async fn send(&self, result: &impl Serialize) -> Result<(), DisconnectError>
Send a message on the subscription.
Sourcepub fn subscription_id(&self) -> SubscriptionId<'_>
pub fn subscription_id(&self) -> SubscriptionId<'_>
Get the subscription id.